% -------------------------------------------------------------------------
% INSTITUTE    : University of Western Ontario
% FILENAME     : createICCMatrix.m 
% FILE TYPE    : Function
% VERSION      : 2.0
% AUTHOR       : Anthony Bertone
% -------------------------------------------------------------------------
% REVISION HISTORY
% -------------------------------------------------------------------------
% 
%  1.0, 2010-09, Drew Morris (drew.j.morris@gmail.com)
%    - Initial Release
%  2.0, 2014-08-05, Anthony Bertone (anthony.m.bertone@gmail.com)
%    - Modified Version
%
% -------------------------------------------------------------------------
% DESCRIPTION
% -------------------------------------------------------------------------
%
% Creates a matrix D composed of the data coming from the subject array S &
% grand average structure GA.
% - channels is a list of channels to be analyzed, returned from
% readSelectedChannels
% - baseCat is a string indicating the segment that is the base for ICC
% analysis
% - window_start is the beginning of the window you wish to include in the
% data matrix
% - window_end is the end of the window you wish to include in the data
% matrix
%
% D will be a NxMxP array
%   N rows of samples
%   M columns of categories
%   P pages of different subjects/channels
%
% case_labels are text case_labels of which column/page corresponds to 
% which data. 
%
% -------------------------------------------------------------------------
% -------------------------------------------------------------------------
% -------------------------------------------------------------------------

function [D, case_labels, comp_labels] = createIccDataMatrix(S, GA, cc, channels, baseCat, window_start, window_end)

    window_indices = find( S.patient(1, 1).data.segment.timeData >= window_start & ...
                         S.patient(1, 1).data.segment.timeData  <= window_end );
    
    channel_indices = zeros([length(channels) 1]);
    for ch = 1:length(channels)
        channel_indices(ch) = find(strcmp(S.patient(1, 1).data.channelName, channels{ch}));
    end

    % Initalize empty cell arrays
    D = zeros([length(window_indices)  S.patient(1, 1).data.segments  length(S)*length(channels)]);
    case_labels = cell( [double(S.patient(1, 1).data.segments) double(1*length(channels))] );
    comp_labels = cell([double(length(GA(1, 1).average ) + 2) 1]);    % +2 allows for an empty cell above & below titles

    for ch = 1:length(channel_indices)
       D(:,1,ch) = S.patient(1, cc).data.segment.channelData(channel_indices(ch),window_indices);
       case_labels{1,ch} = sprintf('Subject: %s  Channel: %s (c%03d)', S.patient(1, cc).filename, channels{ch}, channel_indices(ch) );
       case_labels{2,ch} = [];  % row of null characters
       for ss = 2:(length(GA(1, 1).average) + 1)
           D(:,ss,ch) = GA(1, cc).average{1, ss-1}(channel_indices(ch),window_indices);
           comp_labels{ss,1} = sprintf('%s vs %s', GA(1, 1).title{1, ss-1}, baseCat);
       end
    end


    