% -------------------------------------------------------------------------
% INSTITUTE    : University of Western Ontario
% FILENAME     : extract_data.m 
% FILE TYPE    : Function
% VERSION      : 1.0
% AUTHOR       : Anthony Bertone
% -------------------------------------------------------------------------
% REVISION HISTORY
% -------------------------------------------------------------------------
% 
%  1.0, 2014-08-05, Anthony Bertone (anthony.m.bertone@gmail.com)
%    - Initial Release
%
% -------------------------------------------------------------------------
% DESCRIPTION
% -------------------------------------------------------------------------
%  
%  Extract participant's .raw file data and store in corresponding 
%  structure (S.patient(xx).data).  
%  Process is repeated -- based on the number of participants listed in 
%  age_ICC_subjectList.txt
%
% -------------------------------------------------------------------------
% -------------------------------------------------------------------------
% -------------------------------------------------------------------------

function S = extract_data( S, data_path, channel_names, time0code, byte_swap )

    for xx = 1:numel(S.patient)

        a = S.patient(xx).folder;  % folder position
        cd( fullfile(data_path, char(S.raw_foldername{a, 1}))) ;
        
        % read and copy .raw file data into corresponding patient structure. 
        try
            S.patient(xx).data = read_egi_simple_bin(char(S.patient(xx).filename), byte_swap, channel_names, time0code);
        catch e
            error(['Problem extracting file "' S.patient(xx).filename '". ' e.message]); 
        end
        
    end
    
end





